@@ -349,6 +349,37 @@ namespace Magick
     // Label image
     void            label ( const std::string &label_ );
 
+    // Level image. Adjust the levels of the image by scaling the
+    // colors falling between specified white and black points to the
+    // full available quantum range. The parameters provided represent
+    // the black, mid (gamma), and white points.  The black point
+    // specifies the darkest color in the image. Colors darker than
+    // the black point are set to zero. Mid point (gamma) specifies a
+    // gamma correction to apply to the image. White point specifies
+    // the lightest color in the image.  Colors brighter than the
+    // white point are set to the maximum quantum value. The black and
+    // white point have the valid range 0 to QuantumRange while mid (gamma)
+    // has a useful range of 0 to ten.
+    void            level ( const double black_point,
+                            const double white_point,
+                            const double mid_point=1.0 );
+
+    // Level image channel. Adjust the levels of the image channel by
+    // scaling the values falling between specified white and black
+    // points to the full available quantum range. The parameters
+    // provided represent the black, mid (gamma), and white points.
+    // The black point specifies the darkest color in the
+    // image. Colors darker than the black point are set to zero. Mid
+    // point (gamma) specifies a gamma correction to apply to the
+    // image. White point specifies the lightest color in the image.
+    // Colors brighter than the white point are set to the maximum
+    // quantum value. The black and white point have the valid range 0
+    // to QuantumRange while mid (gamma) has a useful range of 0 to ten.
+    void            levelChannel ( const ChannelType channel,
+                                   const double black_point,
+                                   const double white_point,
+                                   const double mid_point=1.0 );
+
     // Magnify image by integral size
     void            magnify ( void );
     
@@ -389,7 +420,7 @@ namespace Magick
     // pixels are opaque then they are set to the specified opacity
     // value, otherwise they are blended with the supplied opacity
     // value.  The value of opacity_ ranges from 0 (completely opaque)
-    // to MaxRGB. The defines OpaqueOpacity and TransparentOpacity are
+    // to QuantumRange. The defines OpaqueOpacity and TransparentOpacity are
     // available to specify completely opaque or completely
     // transparent, respectively.
     void            opacity ( const unsigned int opacity_ );
@@ -483,6 +514,9 @@ namespace Magick
     void            reduceNoise ( void );
     void            reduceNoise ( const double order_ );
     
+    // Resize image to specified size.
+    void            resize ( const Geometry &geometry_ );
+
     // Roll image (rolls image vertically and horizontally) by specified
     // number of columnms and rows)
     void            roll ( const Geometry &roll_ );
@@ -524,6 +558,9 @@ namespace Magick
     void            shear ( const double xShearAngle_,
           const double yShearAngle_ );
     
+    // adjust the image contrast with a non-linear sigmoidal contrast algorithm
+    void            sigmoidalContrast ( const unsigned int sharpen_, const double contrast, const double midpoint = QuantumRange / 2.0 );
+
     // Solarize image (similar to effect seen when exposing a
     // photographic film to light during the development process)
     void            solarize ( const double factor_ = 50.0 );
@@ -778,6 +815,10 @@ namespace Magick
     void            endian ( const EndianType endian_ );
     EndianType      endian ( void ) const;
 
+    // Exif profile (BLOB)
+    void exifProfile( const Blob& exifProfile_ );
+    Blob exifProfile( void ) const; 
+
     // Image file name
     void            fileName ( const std::string &fileName_ );
     std::string     fileName ( void ) const;
@@ -913,6 +954,10 @@ typedef struct _ImageStatistics
     // color reduced.
     double          normalizedMeanError ( void ) const;
 
+    // Image orientation
+    void            orientation ( const OrientationType orientation_ );
+    OrientationType orientation ( void ) const;
+
     // Preferred size and location of an image canvas.
     void            page ( const Geometry &pageSize_ );
     Geometry        page ( void ) const;
