@@ -1,8 +1,22 @@
 /*
-  ImageMagick version and copyright.
+  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  dedicated to making software imaging solutions freely available.
+  
+  You may not use this file except in compliance with the License.
+  obtain a copy of the License at
+  
+    http://www.imagemagick.org/script/license.php
+  
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+
+  MagickCore version methods.
 */
-#ifndef _MAGICK_VERSION_H
-#define _MAGICK_VERSION_H
+#ifndef _MAGICKCORE_VERSION_H
+#define _MAGICKCORE_VERSION_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -12,10 +26,10 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2005 ImageMagick Studio LLC"
-#define MagickLibVersion  0x623
-#define MagickLibVersionText  "6.2.3"
-#define MagickLibVersionNumber  6.2.3,3
+#define MagickCopyright  "Copyright (C) 1999-2006 ImageMagick Studio LLC"
+#define MagickLibVersion  0x628
+#define MagickLibVersionText  "6.2.8"
+#define MagickLibVersionNumber  6,2,8,8
 #if (QuantumDepth == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -25,11 +39,14 @@ extern "C" {
 #elif (QuantumDepth == 32)
 #define MagickQuantumDepth  "Q32"
 #define MagickQuantumRange  "4294967295"
+#elif (QuantumDepth == 64)
+#define MagickQuantumDepth  "Q64"
+#define MagickQuantumRange  "18446744073709551615"
 #else
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#define MagickReleaseDate  "07/13/05"
+#define MagickReleaseDate  "08/15/06"
 #define MagickVersion MagickPackageName " " MagickLibVersionText " " \
   MagickReleaseDate " " MagickQuantumDepth " " MagickHomeURL
 #define MagickHomeURL  "http://www.imagemagick.org"
